@@ -1,6 +1,61 @@
 var NAVTREEINDEX3 =
 {
-"group__encoder.html#gga92b6709b58dc3435e3ba652da562eda1a621c3f07937527618dc06e962425f6cc":[12,0,1,25,2],
+"group__cyclic__refresh.html#gafc1304a44c092d497a6cbbbaef92d1b9":[12,2,9,10],
+"group__decoder.html":[12,0,0],
+"group__decoder.html#ga23378c7ca8c361c097181aaaa2a5a734":[12,0,0,4],
+"group__decoder.html#ga2544bac9fdc439f0effd6b1b14df54be":[12,0,0,10],
+"group__decoder.html#ga2b456cf67b1b64dabed370c5d7514b29":[12,0,0,11],
+"group__decoder.html#ga67b2d2d0bfa394bbbd1c5ce4876ed48c":[12,0,0,7],
+"group__decoder.html#ga9ee6dac1fc46ab5c254395eea5469d5d":[12,0,0,13],
+"group__decoder.html#gab03fdb999d1f83a5896869a3ba5f68f7":[12,0,0,12],
+"group__decoder.html#gab2bfd2f5517b9452d2c71b7c2b2e8e8d":[12,0,0,9],
+"group__decoder.html#gab456f6df8429a23dce32438f0a570ef6":[12,0,0,8],
+"group__decoder.html#gabd11df9f35d52ea76de2c8d32aa36963":[12,0,0,5],
+"group__decoder.html#gafdbfca65b19ab1f6d72b32cd01753b9b":[12,0,0,6],
+"group__encoder.html":[12,0,1],
+"group__encoder.html#ga03ca3defc61e1d70c34e9d94e7cee823":[12,0,1,14],
+"group__encoder.html#ga10e276f2fa8fe789b69c029404e6ed15":[12,0,1,28],
+"group__encoder.html#ga205cf6f9460f4b4a842872012ef6fb0c":[12,0,1,29],
+"group__encoder.html#ga264a9b5466698e980b8c37d133ae6043":[12,0,1,16],
+"group__encoder.html#ga4118658e1fc1590f72fec38478ae230d":[12,0,1,11],
+"group__encoder.html#ga45654d08fa4708e374af8aae73c943ac":[12,0,1,35],
+"group__encoder.html#ga54cbc3acf8791a8809139b101ae68a1b":[12,0,1,19],
+"group__encoder.html#ga5f326af84993f371bb165883bb5a5a59":[12,0,1,18],
+"group__encoder.html#ga608725216f15096fa209d30fef121c1c":[12,0,1,8],
+"group__encoder.html#ga67b338974dd0a21cefec71d152dd5f51":[12,0,1,34],
+"group__encoder.html#ga6f4a777de5389771e783df7ff1f116d4":[12,0,1,33],
+"group__encoder.html#ga7c084d3ecef569aad166ce70b0e8a957":[12,0,1,26],
+"group__encoder.html#ga7e32e8290b36ed5be2ecf6ef09a94973":[12,0,1,36],
+"group__encoder.html#ga86a6a9053205149cccc98481b5460337":[12,0,1,12],
+"group__encoder.html#ga92b6709b58dc3435e3ba652da562eda1":[12,0,1,25],
+"group__encoder.html#gaa937bad4eb45a2533c7d7801c4d975a1":[12,0,1,20],
+"group__encoder.html#gaab769c729ea1273fe722dbfbff9d4c9c":[12,0,1,17],
+"group__encoder.html#gaade68a7d33d30f97dc9a596aa5e065d8":[12,0,1,13],
+"group__encoder.html#gaaf72058c11fcf006c41662114997e12c":[12,0,1,7],
+"group__encoder.html#gabe40293fd7d1aaa2a642c41716c26f68":[12,0,1,30],
+"group__encoder.html#gabf8173fa6a1419e7e6798df8493fc562":[12,0,1,21],
+"group__encoder.html#gac0498fc02cd368e6d9675cdb0bab5a84":[12,0,1,27],
+"group__encoder.html#gacbef92200b831adb94283f84128f83de":[12,0,1,22],
+"group__encoder.html#gaccf857f83c29408e5aff2c918c464ba4":[12,0,1,32],
+"group__encoder.html#gade71d5d928a6a975bcc6e404d652cba4":[12,0,1,23],
+"group__encoder.html#gae2cc24d3083099df8eb60ad65f81c62f":[12,0,1,15],
+"group__encoder.html#gae30bbbdef18e9da3631b69c170533e92":[12,0,1,10],
+"group__encoder.html#gae4af664f2049d5b7d7b644d9a61d497c":[12,0,1,6],
+"group__encoder.html#gae722c9f9ba9b4ca8dba6bbe7c0692024":[12,0,1,9],
+"group__encoder.html#gaf4a4c3c3c91dd92c960990f6e534271d":[12,0,1,31],
+"group__encoder.html#gafeb69da4a9649a54e805f59c26d8dfed":[12,0,1,24],
+"group__encoder.html#gga10e276f2fa8fe789b69c029404e6ed15a2f3d27caf9b7e9686f087b5f3b0d713a":[12,0,1,28,2],
+"group__encoder.html#gga10e276f2fa8fe789b69c029404e6ed15a3197eacb02a2d3842f4b04bc86207f7a":[12,0,1,28,3],
+"group__encoder.html#gga10e276f2fa8fe789b69c029404e6ed15acf501f7a5d8673fa7546aa891c357ed3":[12,0,1,28,0],
+"group__encoder.html#gga10e276f2fa8fe789b69c029404e6ed15aee3c6d6fa67efdaa571a59a6ac531dcc":[12,0,1,28,1],
+"group__encoder.html#gga7c084d3ecef569aad166ce70b0e8a957a14b6057d61c61e6117f5af16dcf89b0c":[12,0,1,26,1],
+"group__encoder.html#gga7c084d3ecef569aad166ce70b0e8a957a70aa1f15e91f6576ba3e63879947be64":[12,0,1,26,2],
+"group__encoder.html#gga7c084d3ecef569aad166ce70b0e8a957a7d3a2574737ea63d0f160ffdbd7f0110":[12,0,1,26,0],
+"group__encoder.html#gga7c084d3ecef569aad166ce70b0e8a957aff3bbd4fe870b4b946c2093e59eb14e5":[12,0,1,26,3],
+"group__encoder.html#gga92b6709b58dc3435e3ba652da562eda1a1b4b8ee9c1910fc59ac9dfd9700f3f02":[12,0,1,25,0],
+"group__encoder.html#gga92b6709b58dc3435e3ba652da562eda1a606e695b3dd96b1875bdae681ba6313d":[12,0,1,25,2],
+"group__encoder.html#gga92b6709b58dc3435e3ba652da562eda1a621c3f07937527618dc06e962425f6cc":[12,0,1,25,4],
+"group__encoder.html#gga92b6709b58dc3435e3ba652da562eda1a89ebdde284dd2568df883658bdf3f8f7":[12,0,1,25,3],
 "group__encoder.html#gga92b6709b58dc3435e3ba652da562eda1ad342b33a290482c20238bfde5d9bea1e":[12,0,1,25,1],
 "group__encoder.html#ggac0498fc02cd368e6d9675cdb0bab5a84a8d6f57a670b8bd8f11dae3e89acedb1d":[12,0,1,27,0],
 "group__encoder.html#ggac0498fc02cd368e6d9675cdb0bab5a84aea1965a235dea1b99d2b52145be35d4e":[12,0,1,27,1],
@@ -12,31 +67,30 @@ var NAVTREEINDEX3 =
 "group__encoder.html#ggafeb69da4a9649a54e805f59c26d8dfedaaa76df44da4c92b08150b8a5326f5ebe":[12,0,1,24,2],
 "group__encoder__algo.html":[12,2],
 "group__gf__group__algo.html":[12,2,0,6],
-"group__gf__group__algo.html#ga2572624930ccd545e17d9d7429702177":[12,2,0,6,3],
 "group__gf__group__algo.html#ga294931863e7bb9104cdab552e06dbbd9":[12,2,0,6,0],
+"group__gf__group__algo.html#ga67628538a2f36718ec7c924ce5328de2":[12,2,0,6,3],
 "group__gf__group__algo.html#ga89a0a5ad12dd9a8d35030ab51d5c4fe5":[12,2,0,6,1],
 "group__gf__group__algo.html#ga9aa97f1bc97fd44160e858d375c0c20f":[12,2,0,6,4],
-"group__gf__group__algo.html#gaca4e37ba8099a3e26ab910b4b9a367c3":[12,2,0,6,2],
+"group__gf__group__algo.html#ga9b50f914d4997b65c3945a185393fe82":[12,2,0,6,2],
 "group__high__level__algo.html":[12,2,0],
 "group__high__level__algo.html#ga0d530935e53f27ab76f0dada5a8b94b6":[12,2,0,16],
 "group__high__level__algo.html#ga0f59145ac0765033ee267ba203baed23":[12,2,0,12],
+"group__high__level__algo.html#ga29eed659e71f7b8e1aef31d8cb4bb9ea":[12,2,0,7],
+"group__high__level__algo.html#ga4017ec9e9cfd7bd461775266c80ff46d":[12,2,0,18],
 "group__high__level__algo.html#ga681c10fbb05a4c91b4536107f3342c37":[12,2,0,17],
-"group__high__level__algo.html#ga695a997630cf37aac9ee18efb8f92d50":[12,2,0,8],
+"group__high__level__algo.html#ga6b56870ab498cf798e1e16c38b4c197c":[12,2,0,8],
 "group__high__level__algo.html#ga7c707e2dc0a45e03ee9cd81f97552a0b":[12,2,0,9],
 "group__high__level__algo.html#ga7d1e860d1b77466051044c86dff13528":[12,2,0,11],
 "group__high__level__algo.html#ga87fccf520455ff9a41aa381b40b8862c":[12,2,0,13],
 "group__high__level__algo.html#ga9f2d93e66cde2eccb5f4dcd5d08c6d6a":[12,2,0,10],
 "group__high__level__algo.html#gac237dcb6e36d4dbff616e618ab4985a6":[12,2,0,14],
-"group__high__level__algo.html#gac2ee6452d48ca44684f208abda614b62":[12,2,0,7],
 "group__high__level__algo.html#gad4f93a0174051f16f9010f332f6c9bc7":[12,2,0,19],
-"group__high__level__algo.html#gae1ceea4df4210e2464865ea90d5aa9ca":[12,2,0,18],
 "group__high__level__algo.html#gaec07a41d07f7cd08a258531cd8935c68":[12,2,0,15],
 "group__in__loop__cdef.html":[12,2,7],
-"group__in__loop__cdef.html#gabe4a73568753867bfca1f429f6064f64":[12,2,7,1],
-"group__in__loop__cdef.html#gacc8b2a0c9ebecd3df006d4e0733c67fb":[12,2,7,0],
+"group__in__loop__cdef.html#ga5b538a84b16b2852308935702e58eef7":[12,2,7,1],
+"group__in__loop__cdef.html#ga954983bebf726d3c6a4977410dfc607f":[12,2,7,0],
 "group__in__loop__filter.html":[12,2,6],
-"group__in__loop__filter.html#ga380290fdff07ec7b4ad5d768c676176d":[12,2,6,1],
-"group__in__loop__filter.html#gab53821e5198a56be84ddda295a4f72be":[12,2,6,0],
+"group__in__loop__filter.html#ga380290fdff07ec7b4ad5d768c676176d":[12,2,6,0],
 "group__in__loop__restoration.html":[12,2,8],
 "group__in__loop__restoration.html#ga476124fb6e4f853a2705bb32a56432b2":[12,2,8,2],
 "group__in__loop__restoration.html#ga65482f59379cfb1236341521d4c99391":[12,2,8,1],
@@ -45,27 +99,26 @@ var NAVTREEINDEX3 =
 "group__inter__mode__search.html#ga43b5823e9da166d41854f95ae1d87f5f":[12,2,3,3],
 "group__inter__mode__search.html#ga6770282723e2dcac945834330e8715ae":[12,2,3,2],
 "group__inter__mode__search.html#ga73e0bb6197788ab4a8d496cac4e9601c":[12,2,3,0],
-"group__inter__mode__search.html#gabca3ba731d46a73fbdf81201dbcf50d2":[12,2,3,4],
+"group__inter__mode__search.html#gabca3ba731d46a73fbdf81201dbcf50d2":[12,2,3,5],
+"group__inter__mode__search.html#gac177628bc567531418befbed2c2526bf":[12,2,3,4],
 "group__inter__mode__search.html#gae1aedf721583700393db3502d6042350":[12,2,3,1],
 "group__intra__mode__search.html":[12,2,2],
-"group__intra__mode__search.html#ga09b52d574bf6adce4b334abad46ef35b":[12,2,2,3],
-"group__intra__mode__search.html#ga0e87b8bff130a587c69cf28c2dc9e59a":[12,2,2,8],
-"group__intra__mode__search.html#ga1f6f374f792d71c79d53949a185799d6":[12,2,2,19],
-"group__intra__mode__search.html#ga3dba7f81ba3f8ca55df5dc98f871f8e8":[12,2,2,12],
+"group__intra__mode__search.html#ga1f6f374f792d71c79d53949a185799d6":[12,2,2,17],
+"group__intra__mode__search.html#ga3a03891b3b454db9c4446f779d3bfa44":[12,2,2,8],
+"group__intra__mode__search.html#ga3dba7f81ba3f8ca55df5dc98f871f8e8":[12,2,2,11],
 "group__intra__mode__search.html#ga46ac7127978a1310a85adc9a1e878668":[12,2,2,4],
 "group__intra__mode__search.html#ga520ae1e2beb80b7b069e71dc0c881f6f":[12,2,2,5],
-"group__intra__mode__search.html#ga54a3be2975508906034952fea34e6556":[12,2,2,16],
-"group__intra__mode__search.html#ga592fed21d73cb4034c0eca70da7fae1c":[12,2,2,15],
-"group__intra__mode__search.html#ga5c63552bf8f204e19cae7adfc6185b3a":[12,2,2,14],
+"group__intra__mode__search.html#ga54a3be2975508906034952fea34e6556":[12,2,2,14],
+"group__intra__mode__search.html#ga592fed21d73cb4034c0eca70da7fae1c":[12,2,2,13],
+"group__intra__mode__search.html#ga5c63552bf8f204e19cae7adfc6185b3a":[12,2,2,12],
 "group__intra__mode__search.html#ga5d1279f833651cdbb96966d83076f563":[12,2,2,6],
-"group__intra__mode__search.html#ga7564843be9eaba3867709cbbee53e0f6":[12,2,2,11],
 "group__intra__mode__search.html#ga868a4e2cc95d1134e057ebf3a320c07a":[12,2,2,7],
-"group__intra__mode__search.html#ga888b8c7618a6df45a38e48f52e020ced":[12,2,2,18],
-"group__intra__mode__search.html#ga8f5e96e865ec83e37cb62fe69882a259":[12,2,2,10],
-"group__intra__mode__search.html#gac2e398a4d95387b5eefaf149a91c9581":[12,2,2,9],
+"group__intra__mode__search.html#ga888b8c7618a6df45a38e48f52e020ced":[12,2,2,16],
+"group__intra__mode__search.html#ga8f5e96e865ec83e37cb62fe69882a259":[12,2,2,9],
+"group__intra__mode__search.html#gab0adec0117540b9786dd57688c8020b0":[12,2,2,10],
 "group__intra__mode__search.html#gae234e4fbb4d2abad145f4353595fd8e6":[12,2,2,2],
-"group__intra__mode__search.html#gafa28ef0b6fdbcde62d60ab5333944690":[12,2,2,17],
-"group__intra__mode__search.html#gafa48bd67ee58e2c24eb38f7af6b36d63":[12,2,2,13],
+"group__intra__mode__search.html#gaf72915b72e91552643b40aa506ed426d":[12,2,2,3],
+"group__intra__mode__search.html#gafa28ef0b6fdbcde62d60ab5333944690":[12,2,2,15],
 "group__look__ahead__buffer.html":[12,2,0,5],
 "group__nonrd__mode__search.html":[12,2,12],
 "group__nonrd__mode__search.html#ga328360c35ea0f27804a7e649ea5d422a":[12,2,12,3],
@@ -79,15 +132,15 @@ var NAVTREEINDEX3 =
 "group__nonrd__mode__search.html#gaffa694231a7a96578aa3572049b9aa51":[12,2,12,4],
 "group__palette__mode__search.html":[12,2,2,0],
 "group__palette__mode__search.html#ga0865030d0ffa042390ab2472e77f957d":[12,2,2,0,0],
-"group__palette__mode__search.html#ga29331edd94008ed29de2aee5230c62dd":[12,2,2,0,7],
 "group__palette__mode__search.html#ga2cb9b1049cdc0060881083633ccee68f":[12,2,2,0,5],
 "group__palette__mode__search.html#ga3ef821348e6d88fc171a8af5d070a5ca":[12,2,2,0,3],
 "group__palette__mode__search.html#ga499204b04894f62208ecd7481fd837ac":[12,2,2,0,2],
 "group__palette__mode__search.html#ga4c2ba8b9ea7370f75f364481f0aec9a3":[12,2,2,0,1],
-"group__palette__mode__search.html#ga640d456c75721af1057dc35c50832f36":[12,2,2,0,9],
+"group__palette__mode__search.html#ga5a3719d514a1fc927159d4af8f98f11c":[12,2,2,0,7],
 "group__palette__mode__search.html#ga79e23cb5955092ba04bee379e97df918":[12,2,2,0,8],
 "group__palette__mode__search.html#gaa6a39d9de82e0e5cd963473067334e17":[12,2,2,0,4],
 "group__palette__mode__search.html#gab9bf846634be27493a882c390fd7bc55":[12,2,2,0,6],
+"group__palette__mode__search.html#gaea1f7a58c572de818564b309cf7c70e7":[12,2,2,0,9],
 "group__partition__search.html":[12,2,1],
 "group__partition__search.html#ga0664c147707f2d528d53cc09a7f41e20":[12,2,1,6],
 "group__partition__search.html#ga0d32a492481d81049254d362c3046d41":[12,2,1,2],
@@ -103,37 +156,44 @@ var NAVTREEINDEX3 =
 "group__partition__search.html#gacf0e64a22f62c95a3f8512f1cf0ec716":[12,2,1,1],
 "group__partition__search.html#gad9561a1da5a2377a8fa76435c8facef2":[12,2,1,10],
 "group__rate__control.html":[12,2,0,2],
-"group__rate__control.html#ga06eb20a95903f261d8e9a86f6a359927":[12,2,0,2,16],
-"group__rate__control.html#ga08d8e6c33750a282d5a9dc66252fda45":[12,2,0,2,30],
-"group__rate__control.html#ga174d96c77a72a090d5e218346a91d4c2":[12,2,0,2,22],
-"group__rate__control.html#ga204806353e37338b8d901c79dbc39523":[12,2,0,2,20],
-"group__rate__control.html#ga2739ae83fcd1266a2b44aae1ee40e57f":[12,2,0,2,7],
-"group__rate__control.html#ga2a0f590eb2dc358f9781654644a2519d":[12,2,0,2,0],
-"group__rate__control.html#ga4770b9bf9d2f350267d57a8dcc48d0a2":[12,2,0,2,18],
-"group__rate__control.html#ga4d75c27a723a602ab5b4c497cea07993":[12,2,0,2,27],
-"group__rate__control.html#ga653667e5cc76259acc233c1986546599":[12,2,0,2,24],
-"group__rate__control.html#ga671ccd88dfed2d5be8f6c586910ab89e":[12,2,0,2,15],
-"group__rate__control.html#ga6853e4fcc63f2f54ae429e27286827ae":[12,2,0,2,1],
-"group__rate__control.html#ga7778c29e995a78b2521fe4f0bab0c9c1":[12,2,0,2,17],
-"group__rate__control.html#ga788dbcf3c2f97056f0ca1fd644a4535f":[12,2,0,2,14],
-"group__rate__control.html#ga8cc1e01e3fb0a620ea3a7ab53d94eb6e":[12,2,0,2,9],
-"group__rate__control.html#ga9c1efbd9f79914ed44ee7a6a795381d5":[12,2,0,2,28],
-"group__rate__control.html#gaa1b79c4de593c5ddccf4f0384d51e901":[12,2,0,2,6],
-"group__rate__control.html#gaa5b125ad159f53b6ee5423900e479c0b":[12,2,0,2,3],
-"group__rate__control.html#gab0e270ba5341f6881b20970a82567eae":[12,2,0,2,11],
-"group__rate__control.html#gab8e7c90f91decf78f31360e56b7f1be6":[12,2,0,2,25],
-"group__rate__control.html#gabbdc0f8c7b275c67917af9e49a0a18ce":[12,2,0,2,13],
-"group__rate__control.html#gabc57b9de63d930432a3ed6ee98206c96":[12,2,0,2,12],
-"group__rate__control.html#gac12d62af325ff26685a28bebb0137a65":[12,2,0,2,2],
-"group__rate__control.html#gac4b060420e6d43e341ce36cadbb2ff93":[12,2,0,2,23],
-"group__rate__control.html#gacd9a4ebbc3f3c5203419152558dcb17a":[12,2,0,2,29],
-"group__rate__control.html#gacff14724140f9a2419bc82ef61ef2845":[12,2,0,2,21],
-"group__rate__control.html#gad9722dabdd6c62b9d2fac0551b83fe89":[12,2,0,2,10],
-"group__rate__control.html#gae79c4d7e1bb558a1c2b4cd9da69b77c7":[12,2,0,2,26],
-"group__rate__control.html#gae9e6431ebd75ca58a1e526f91cc0cea8":[12,2,0,2,8],
-"group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544":[12,2,0,2,4],
-"group__rate__control.html#gaf4845f52af8f34c200706e1c3e14614f":[12,2,0,2,19],
-"group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f":[12,2,0,2,5],
+"group__rate__control.html#ga05ee091c593e5672c6be2d0bdd89d1cb":[12,2,0,2,4],
+"group__rate__control.html#ga06eb20a95903f261d8e9a86f6a359927":[12,2,0,2,23],
+"group__rate__control.html#ga08d8e6c33750a282d5a9dc66252fda45":[12,2,0,2,37],
+"group__rate__control.html#ga174d96c77a72a090d5e218346a91d4c2":[12,2,0,2,29],
+"group__rate__control.html#ga1930a02e62c42b75313b987806837c84":[12,2,0,2,5],
+"group__rate__control.html#ga1f1b566e7234deb8018a0bd3dc3822d7":[12,2,0,2,1],
+"group__rate__control.html#ga2739ae83fcd1266a2b44aae1ee40e57f":[12,2,0,2,15],
+"group__rate__control.html#ga2a0f590eb2dc358f9781654644a2519d":[12,2,0,2,8],
+"group__rate__control.html#ga45ce59a77756df79d6fdbdae82158a41":[12,2,0,2,2],
+"group__rate__control.html#ga4770b9bf9d2f350267d57a8dcc48d0a2":[12,2,0,2,25],
+"group__rate__control.html#ga4d75c27a723a602ab5b4c497cea07993":[12,2,0,2,34],
+"group__rate__control.html#ga653667e5cc76259acc233c1986546599":[12,2,0,2,31],
+"group__rate__control.html#ga671ccd88dfed2d5be8f6c586910ab89e":[12,2,0,2,22],
+"group__rate__control.html#ga6853e4fcc63f2f54ae429e27286827ae":[12,2,0,2,9],
+"group__rate__control.html#ga697e00462bcbc3165ed0f7bd25a88925":[12,2,0,2,0],
+"group__rate__control.html#ga6ae4ccee614dac82eb20d16c30d6cbe9":[12,2,0,2,7],
+"group__rate__control.html#ga7778c29e995a78b2521fe4f0bab0c9c1":[12,2,0,2,24],
+"group__rate__control.html#ga788dbcf3c2f97056f0ca1fd644a4535f":[12,2,0,2,21],
+"group__rate__control.html#ga81e2619f5917dda2803f37c76080c3e5":[12,2,0,2,3],
+"group__rate__control.html#ga8cc1e01e3fb0a620ea3a7ab53d94eb6e":[12,2,0,2,17],
+"group__rate__control.html#ga9c1efbd9f79914ed44ee7a6a795381d5":[12,2,0,2,35],
+"group__rate__control.html#gaa1b79c4de593c5ddccf4f0384d51e901":[12,2,0,2,14],
+"group__rate__control.html#gaa5b125ad159f53b6ee5423900e479c0b":[12,2,0,2,11],
+"group__rate__control.html#gaabc94f144903517a3d4aff8f65da1638":[12,2,0,2,27],
+"group__rate__control.html#gab8e7c90f91decf78f31360e56b7f1be6":[12,2,0,2,32],
+"group__rate__control.html#gabbdc0f8c7b275c67917af9e49a0a18ce":[12,2,0,2,20],
+"group__rate__control.html#gabfb0989110479fa704a1b245a4c4c1cf":[12,2,0,2,19],
+"group__rate__control.html#gac12d62af325ff26685a28bebb0137a65":[12,2,0,2,10],
+"group__rate__control.html#gac4b060420e6d43e341ce36cadbb2ff93":[12,2,0,2,30],
+"group__rate__control.html#gacd9a4ebbc3f3c5203419152558dcb17a":[12,2,0,2,36],
+"group__rate__control.html#gacff14724140f9a2419bc82ef61ef2845":[12,2,0,2,28],
+"group__rate__control.html#gad9722dabdd6c62b9d2fac0551b83fe89":[12,2,0,2,18],
+"group__rate__control.html#gadfe05128d22bba397120763fe132c867":[12,2,0,2,6],
+"group__rate__control.html#gae79c4d7e1bb558a1c2b4cd9da69b77c7":[12,2,0,2,33],
+"group__rate__control.html#gae9e6431ebd75ca58a1e526f91cc0cea8":[12,2,0,2,16],
+"group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544":[12,2,0,2,12],
+"group__rate__control.html#gaf4845f52af8f34c200706e1c3e14614f":[12,2,0,2,26],
+"group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f":[12,2,0,2,13],
 "group__speed__features.html":[12,2,0,0],
 "group__speed__features.html#ga375df45f353341a53823feb529182b2a":[12,2,0,0,0],
 "group__speed__features.html#ga643ab0df2f1abcad7bcd6a612fdbc8a2":[12,2,0,0,2],
@@ -169,14 +229,15 @@ var NAVTREEINDEX3 =
 "index.html#main_startpoints":[0,1],
 "index.html#main_support":[2],
 "intra__mode__search_8h.html":[14,0,2,2,8],
+"intra__mode__search_8h.html#a2ca2fefda6fc9003ad5eb932c651df81":[14,0,2,2,8,10],
 "intra__mode__search_8h.html#a36fe8942d46efb604031987aef180df0":[14,0,2,2,8,6],
 "intra__mode__search_8h.html#ac80bd25ae504f9dc621a5ced8a3e390f":[14,0,2,2,8,7],
+"intra__mode__search_8h.html#ac9f5640d9ece61cd6dbcda9f70fa68d8":[14,0,2,2,8,9],
 "intra__mode__search_8h.html#ade408273088bd18a20b290882c3d5da9":[14,0,2,2,8,8],
 "intra__mode__search_8h_source.html":[14,0,2,2,8],
 "intra__mode__search__utils_8h.html":[14,0,2,2,9],
 "intra__mode__search__utils_8h.html#a3f5fd5a4ab169294e490310fbc930617":[14,0,2,2,9,1],
 "intra__mode__search__utils_8h.html#a5ae6f76f06bf24048b936cd1ed709632":[14,0,2,2,9,0],
-"intra__mode__search__utils_8h.html#a8b84909b2724a9078e0ff6ddac8b5d27":[14,0,2,2,9,2],
 "intra__mode__search__utils_8h_source.html":[14,0,2,2,9],
 "lookahead_8h.html":[14,0,2,2,10],
 "lookahead_8h.html#a057e2ff7a73b405643340cb1d5564653":[14,0,2,2,10,2],
@@ -188,66 +249,5 @@ var NAVTREEINDEX3 =
 "lookahead_8h.html#af061d48eaecd02d50cf646e84426aca1":[14,0,2,2,10,1],
 "lookahead_8h_source.html":[14,0,2,2,10],
 "modules.html":[12],
-"pages.html":[],
-"palette_8h.html":[14,0,2,2,11],
-"palette_8h.html#a4a74357844cac7dba9020e29c704da37":[14,0,2,2,11,9],
-"palette_8h_source.html":[14,0,2,2,11],
-"partition__search_8h_source.html":[14,0,2,2,12],
-"pass2__strategy_8h_source.html":[14,0,2,2,13],
-"pickcdef_8h_source.html":[14,0,2,2,14],
-"picklpf_8h_source.html":[14,0,2,2,15],
-"pickrst_8h_source.html":[14,0,2,2,16],
-"ratectrl_8h_source.html":[14,0,2,2,17],
-"rc__utils_8h_source.html":[14,0,2,2,18],
-"rdopt_8h_source.html":[14,0,2,2,19],
-"readme.html":[5],
-"restoration_8h.html":[14,0,2,0,5],
-"restoration_8h_source.html":[14,0,2,0,5],
-"rfc2119.html":[3],
-"rfc2119.html#MAY":[3,4],
-"rfc2119.html#MUST":[3,0],
-"rfc2119.html#MUSTNOT":[3,1],
-"rfc2119.html#SHOULD":[3,2],
-"rfc2119.html#SHOULDNOT":[3,3],
-"samples.html":[9],
-"speed__features_8h.html":[14,0,2,2,20],
-"speed__features_8h.html#a15215de986649ea6e79616020fcaa05e":[14,0,2,2,20,5],
-"speed__features_8h.html#a15215de986649ea6e79616020fcaa05ea71c4d449501909a68c7a4dd0eff51c73":[14,0,2,2,20,5,0],
-"speed__features_8h.html#a15215de986649ea6e79616020fcaa05ea9471e8a394b564da6e83380542a101cd":[14,0,2,2,20,5,1],
-"speed__features_8h.html#a15215de986649ea6e79616020fcaa05eaaadd43dbe5acff18cf31d400c5060de1":[14,0,2,2,20,5,2],
-"speed__features_8h.html#a15215de986649ea6e79616020fcaa05eaca097aaff2e966e9bf5dfa7afb3ac375":[14,0,2,2,20,5,3],
-"speed__features_8h.html#a4a1fdb5ea677281c3604e8f99ef1d33b":[14,0,2,2,20,3],
-"speed__features_8h.html#a803e1c508d00021beeeb1663d68d00b3":[14,0,2,2,20,2],
-"speed__features_8h.html#af0531e26369694f61a1d06bad088cb38":[14,0,2,2,20,4],
-"speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a19fe571caa99298b7ef9e9562697802e":[14,0,2,2,20,4,2],
-"speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a2fa63007cc3a58f498c748c53fb87158":[14,0,2,2,20,4,1],
-"speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a4f856e769829192cd8ec449baeec2012":[14,0,2,2,20,4,0],
-"speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a54ec658a3a10c249a81c092b0bbfb38c":[14,0,2,2,20,4,6],
-"speed__features_8h.html#af0531e26369694f61a1d06bad088cb38a981856d684f25f09bbc7d48ae85c627e":[14,0,2,2,20,4,5],
-"speed__features_8h.html#af0531e26369694f61a1d06bad088cb38addd2ae3f38d50ef46c4e34309b691a29":[14,0,2,2,20,4,4],
-"speed__features_8h.html#af0531e26369694f61a1d06bad088cb38aefb133e7b51a2554188fb32820b17cb7":[14,0,2,2,20,4,3],
-"speed__features_8h_source.html":[14,0,2,2,20],
-"structAV1Common.html":[13,0,27],
-"structAV1Common.html#a080bf548c8e9caacc1bd25941882a1d9":[13,0,27,25],
-"structAV1Common.html#a0b76d3f1579f97e17fa07fdc88f04edb":[13,0,27,28],
-"structAV1Common.html#a0bf2ab80878f91cdf6d6595aeb9d3b32":[13,0,27,35],
-"structAV1Common.html#a1290b763be1e61a7f5da5156fede6196":[13,0,27,6],
-"structAV1Common.html#a18fc6ef7cde6a5185433a19458e06d68":[13,0,27,9],
-"structAV1Common.html#a1ef81ea62e6360ca5a210582d99e9853":[13,0,27,47],
-"structAV1Common.html#a220cdc4e9d8283b32c65e8b25b57f43e":[13,0,27,16],
-"structAV1Common.html#a2461161e616f79bd29c29dc003a58ec0":[13,0,27,12],
-"structAV1Common.html#a24845cd245fefca67b59b3d99deca3c1":[13,0,27,38],
-"structAV1Common.html#a24ca8d15116bce42bb899f59a256cf21":[13,0,27,43],
-"structAV1Common.html#a27954151ceddfc78e530a024a556e365":[13,0,27,7],
-"structAV1Common.html#a2b3f9e625c8c6d61cfa2a41257799e26":[13,0,27,34],
-"structAV1Common.html#a3044e53588eed52c6623925e6b6651de":[13,0,27,2],
-"structAV1Common.html#a387a9f1f86e2cc412eaa4b47a9070323":[13,0,27,13],
-"structAV1Common.html#a38e7efb5da731cd235a6b5df2657eebe":[13,0,27,32],
-"structAV1Common.html#a3a59c73ba158cb6184c79087851cbf29":[13,0,27,26],
-"structAV1Common.html#a4dc285f68fc19c54e1feca08bd618417":[13,0,27,0],
-"structAV1Common.html#a528f595183529465a33fe657d1289511":[13,0,27,50],
-"structAV1Common.html#a53abe0d94634d1fc0489513e9f31224f":[13,0,27,14],
-"structAV1Common.html#a573a13230af94a43c14f8f4f45d809f9":[13,0,27,48],
-"structAV1Common.html#a6b3ab236119cc699d599594145c08186":[13,0,27,30],
-"structAV1Common.html#a6b7bf72c9d15dc7574565a7e58e21be7":[13,0,27,33]
+"pages.html":[]
 };
